==> vradi-swing-0.0.1-sources.jar: com/jurismarches/vradi/ui/editors/DateEditor.java <==
package com.jurismarches.vradi.ui.editors;

import com.jurismarches.vradi.ui.editors.*;
import java.awt.*;
import java.awt.event.*;
import java.beans.*;
import java.io.*;
import java.lang.*;
import java.util.*;
import javax.swing.*;
import javax.swing.border.*;
import javax.swing.event.*;
import jaxx.runtime.swing.JAXXButtonGroup;
import jaxx.runtime.swing.HBox;
import jaxx.runtime.swing.VBox;
import jaxx.runtime.swing.Table;
import jaxx.runtime.Util;
import jaxx.runtime.SwingUtil;
import static org.nuiton.i18n.I18n._;
import static jaxx.runtime.Util.createImageIcon;
import com.jurismarches.vradi.entities.*;
import com.jurismarches.vradi.services.dto.*;
import com.jurismarches.vradi.VradiContext;
import jaxx.runtime.swing.editor.*;
import jaxx.runtime.swing.EntityComboBox;
import static jaxx.runtime.validator.BeanValidatorUtil.convert;
import static jaxx.runtime.SwingUtil.getStringValue;
import static org.nuiton.i18n.I18n.n_;
import com.jurismarches.vradi.ui.OfferEditHandler;
import org.jdesktop.swingx.JXDatePicker;
import jaxx.runtime.DataBindingListener;

public class DateEditor extends com.jurismarches.vradi.ui.editors.VradiEditor {
    private static String $jaxxObjectDescriptor = "H4sIAAAAAAAAAI1SPW8TQRR8PmwHJ9gBLKIggmQgZbSG2giCHCyIzIcwQhZuWN+t7HXubpfdveRoED+BnwA9DRIdFaKgpqBB/AWEKGgRb+8cnw2HwMVZ2vdmdnZmXn2FklZwbkLjmKgoNDxgZPdav39nOGGu2WHaVVwaoSD9FRxwBrDizc61gQuDroU3p/BmWwRShCycQ7e6sKzNE5/pMWPGwNlFhKt1szcbt2IZqUPWmag81hffvznPvWcvHYBYoroiPqXxL1T2kmIXHO4ZOIk37dOmT8MRylA8HKHeqj1r+1Tr2zRgj+EpLHWhLKlCMgPn///JCUeCj6WB6uYDRT1+3eO4c9HAlisCMokU1wFV7phpsm/nJOKEJTua7FDD0n0pE6KygaJHDTVQsyJJZLifbGXzagpui9AketcXXNEH+EZynw79OUhtc7dvSe5yd4+pSwYaQo3IBKPeM0KmmJjM71jgqkTPzyywY5okSzOzuzCAkorwGOUM/izAPRyl0a//Fr0lTKY/1+qf3n550znMu4B3n8pdnasr5iCVkEwZbq9eTcO2njVvUdkaQEUzH7uedHkjR1hvOkZxeN+JzPIbVI+RorT0+d37tUcfj4DTgWVfUK9D7f5NqJixQheE78Xy6nai6NjBUfwet9rSFNGh2mWbZmPIQw89vhKjBRs5Fsx0DCsfftR7r7fnbTj91/XMitJDKPPQ5yFLij/tdG7RV6RmkSey7ua1uWD/61LKXy29p5pGBAAA";
    private static final long serialVersionUID = 1L;
    protected java.util.Date data;
    private org.jdesktop.swingx.JXDatePicker $JXDatePicker1;
    private DateEditor $VradiEditor0 = this;
    private boolean allComponentsCreated;
    private boolean contextInitialized = true;
    private PropertyChangeListener $DataSource2 = new DataBindingListener(this, "$JXDatePicker1.date");

    /* begin raw body code */    
    
    protected OfferEditHandler getHandler() {
        return getContextValue(OfferEditHandler.class);
    }
    
    protected VradiContext getVradiContext() {
        return VradiContext.get();
    }
    
    void $afterCompleteSetup() {
    }
    /* end raw body code */
    /*---------------------------------------------------------------------------------*/
    /*-- Statics methods --------------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public static jaxx.runtime.JAXXObjectDescriptor $getJAXXObjectDescriptor() {
        return jaxx.runtime.Util.decodeCompressedJAXXObjectDescriptor($jaxxObjectDescriptor);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- Constructors -----------------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public DateEditor() {
        super();
        $initialize();
    }

    public DateEditor(jaxx.runtime.JAXXContext parentContext) {
        super(parentContext);
        $initialize();
    }

    /*---------------------------------------------------------------------------------*/
    /*-- JAXXObject implementation ----------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    @Override
    public void applyDataBinding(String $binding) {
        if ("$JXDatePicker1.date".equals($binding)) {    
            addPropertyChangeListener("data", $DataSource2);
        } else {
            super.applyDataBinding($binding);
            return;
        }
        processDataBinding($binding);
    }

    @Override
    public void processDataBinding(String $dest, boolean $force) {
        if (!$force && $activeBindings.contains($dest)) { 
            return;
        }
        $activeBindings.add($dest);
        try {
            if ("$JXDatePicker1.date".equals($dest)) {
                $JXDatePicker1.setDate(getData());
            } else {
                super.processDataBinding($dest, true);
            }
        } finally {
            $activeBindings.remove($dest);
        }
    }

    @Override
    public void removeDataBinding(String $binding) {
        if ("$JXDatePicker1.date".equals($binding)) {    
            removePropertyChangeListener("data", $DataSource2);
        } else {
            super.removeDataBinding($binding);
        }
    }

    /*---------------------------------------------------------------------------------*/
    /*-- public acessor methods -------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public java.util.Date getData() {
        return data;
    }

    /*---------------------------------------------------------------------------------*/
    /*-- public mutator methods -------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public void setData(java.util.Date newValue) {
        java.util.Date oldValue = this.data;
        this.data = newValue;
        firePropertyChange("data", oldValue, newValue);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- protected acessors methods ---------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    protected org.jdesktop.swingx.JXDatePicker get$JXDatePicker1() {
        return $JXDatePicker1;
    }

    /*---------------------------------------------------------------------------------*/
    /*-- ui creation methods ----------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    private void $completeSetup() {
        allComponentsCreated = true;
        addChildrenToEditorContent();
        // init data bindings
        applyDataBinding("$JXDatePicker1.date");
        $afterCompleteSetup();
    }

    private void $initialize() {
        if (allComponentsCreated || !contextInitialized) {
            return;
        }
        $objectMap.put("$VradiEditor0", this);
        createData();
        // inline creation of $JXDatePicker1
        $objectMap.put("$JXDatePicker1", $JXDatePicker1 = new org.jdesktop.swingx.JXDatePicker());
        $JXDatePicker1.setName("$JXDatePicker1");
        // inline creation of $VradiEditor0
        removeDataBinding("$Table0.name");
        setName("$VradiEditor0");
        
        $completeSetup();
    }

    protected void addChildrenToEditorContent() {
        if (!allComponentsCreated) {
            return;
        }
        editorContent.add($JXDatePicker1, new GridBagConstraints(0, 0, 1, 1, 1.0, 0.0, 10, 2, new Insets(0, 0, 0, 0), 0, 0));
    }

    protected void createData() {
        $objectMap.put("data", data = null);
    }

    @Override
    protected void createEditorContent() {
        $objectMap.put("editorContent", editorContent = new jaxx.runtime.swing.Table());
        editorContent.setName("editorContent");
    }

}

==> vradi-swing-0.0.2-sources.jar: com/jurismarches/vradi/ui/editors/DateEditor.java <==
package com.jurismarches.vradi.ui.editors;

import com.jurismarches.vradi.ui.editors.*;
import java.awt.*;
import java.awt.event.*;
import java.beans.*;
import java.io.*;
import java.lang.*;
import java.util.*;
import javax.swing.*;
import javax.swing.border.*;
import javax.swing.event.*;
import jaxx.runtime.swing.JAXXButtonGroup;
import jaxx.runtime.swing.HBox;
import jaxx.runtime.swing.VBox;
import jaxx.runtime.swing.Table;
import jaxx.runtime.Util;
import jaxx.runtime.SwingUtil;
import static org.nuiton.i18n.I18n._;
import static jaxx.runtime.Util.createImageIcon;
import com.jurismarches.vradi.entities.*;
import com.jurismarches.vradi.services.dto.*;
import com.jurismarches.vradi.VradiContext;
import jaxx.runtime.swing.editor.*;
import jaxx.runtime.swing.EntityComboBox;
import static jaxx.runtime.validator.BeanValidatorUtil.convert;
import static jaxx.runtime.SwingUtil.getStringValue;
import static org.nuiton.i18n.I18n.n_;
import com.jurismarches.vradi.ui.OfferEditHandler;
import org.jdesktop.swingx.JXDatePicker;
import jaxx.runtime.DataBindingListener;

public class DateEditor extends com.jurismarches.vradi.ui.editors.VradiEditor {
    private static String $jaxxObjectDescriptor = "H4sIAAAAAAAAAI1SPW8TQRAdH7aDE5wAFlEQQTKQEu3RG0GQgwWR+RBGyMIN67uVvc7d7bK7lxwN4ifwE6CnQaKjQhTUFDSIv4AQBS1i9s7x2XAIXJylnXlv3rw3r75CRSs4N6FJQlQcGR4ysnut378znDDP7DDtKS6NUJD9Sg44A1jxZ+/awIVB18LdKdxti1CKiEVz6FYXlrV5EjA9ZswYOLuI8LR2e7NyK5GxOmSdiSpiffH9m/Pcf/bSAUgkqivjKs1/ofJNyl1wuG/gJE7ap25AoxHKUDwaod66fWsHVOvbNGSP4SksdaEqqUIyA+f/f+WUI8Un0kB964GiPr/uc+y5ZOCiJ0IyiRXXIVXemGmyb+sk5oSlPZrsUMOyfilToqqBsk8NNbBqRZLY8CDtyuv1DNwWkUn1biy4og9wR3KfDoM5SDWDGGgKNSITjHjPCJn1JmS3bwfc5d4eUxawJtHrMwusmCLJU8xtLg2gomJ8RhmDP4O/h6Us8o3fIreEafXneuPT2y9vOoc5l3D2qcLWuTNF/6USkinD7ei1LGTrlXuLytYAapoFeOPpDW8WCOtNyygO553Irb5B9RgpKkuf371ff/TxCDgdWA4E9TvU9t+EmhkrdEEEfiKvbqeKjh0cxe9xqy1LDx1avWxTbA555KPHVxK0YLPAgpmOYe3Dj0bv9fa8Daf/2p5bUXkIVR4FPGLpwU9vufDAV6RmsS/ymy264pL9b0gpfwE8K5stPgQAAA==";
    private static final long serialVersionUID = 1L;
    protected java.util.Date data;
    protected org.jdesktop.swingx.JXDatePicker editor;
    private DateEditor $VradiEditor0 = this;
    private boolean allComponentsCreated;
    private boolean contextInitialized = true;
    private PropertyChangeListener $DataSource1 = new DataBindingListener(this, "editor.date");

    /* begin raw body code */    
    
    protected OfferEditHandler getHandler() {
        return getContextValue(OfferEditHandler.class);
    }
    
    protected VradiContext getVradiContext() {
        return VradiContext.get();
    }
    
    void $afterCompleteSetup() {
    }
    /* end raw body code */
    /*---------------------------------------------------------------------------------*/
    /*-- Statics methods --------------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public static jaxx.runtime.JAXXObjectDescriptor $getJAXXObjectDescriptor() {
        return jaxx.runtime.Util.decodeCompressedJAXXObjectDescriptor($jaxxObjectDescriptor);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- Constructors -----------------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public DateEditor() {
        super();
        $initialize();
    }

    public DateEditor(jaxx.runtime.JAXXContext parentContext) {
        super(parentContext);
        $initialize();
    }

    /*---------------------------------------------------------------------------------*/
    /*-- JAXXObject implementation ----------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    @Override
    public void applyDataBinding(String $binding) {
        if ("editor.date".equals($binding)) {    
            addPropertyChangeListener("data", $DataSource1);
        } else {
            super.applyDataBinding($binding);
            return;
        }
        processDataBinding($binding);
    }

    @Override
    public void processDataBinding(String $dest, boolean $force) {
        if (!$force && $activeBindings.contains($dest)) { 
            return;
        }
        $activeBindings.add($dest);
        try {
            if ("editor.date".equals($dest)) {
                editor.setDate(getData());
            } else {
                super.processDataBinding($dest, true);
            }
        } finally {
            $activeBindings.remove($dest);
        }
    }

    @Override
    public void removeDataBinding(String $binding) {
        if ("editor.date".equals($binding)) {    
            removePropertyChangeListener("data", $DataSource1);
        } else {
            super.removeDataBinding($binding);
        }
    }

    /*---------------------------------------------------------------------------------*/
    /*-- public acessor methods -------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public java.util.Date getData() {
        return data;
    }

    public org.jdesktop.swingx.JXDatePicker getEditor() {
        return editor;
    }

    /*---------------------------------------------------------------------------------*/
    /*-- public mutator methods -------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public void setData(java.util.Date newValue) {
        java.util.Date oldValue = this.data;
        this.data = newValue;
        firePropertyChange("data", oldValue, newValue);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- ui creation methods ----------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    private void $completeSetup() {
        allComponentsCreated = true;
        addChildrenToEditorContent();
        // init data bindings
        applyDataBinding("editor.date");
        $afterCompleteSetup();
    }

    private void $initialize() {
        if (allComponentsCreated || !contextInitialized) {
            return;
        }
        $objectMap.put("$VradiEditor0", this);
        createData();
        createEditor();
        // inline creation of $VradiEditor0
        removeDataBinding("$Table0.name");
        setName("$VradiEditor0");
        
        $completeSetup();
    }

    protected void addChildrenToEditorContent() {
        if (!allComponentsCreated) {
            return;
        }
        editorContent.add(editor, new GridBagConstraints(0, 0, 1, 1, 1.0, 0.0, 10, 2, new Insets(0, 0, 0, 0), 0, 0));
    }

    protected void createData() {
        $objectMap.put("data", data = null);
    }

    protected void createEditor() {
        $objectMap.put("editor", editor = new org.jdesktop.swingx.JXDatePicker());
        editor.setName("editor");
    }

    @Override
    protected void createEditorContent() {
        $objectMap.put("editorContent", editorContent = new jaxx.runtime.swing.Table());
        editorContent.setName("editorContent");
    }

}
